module Misty::Openstack::API::KeystoneV3_ext
  def tag
    'Identity API Reference v3.10'
  end

  def api_ext
{"/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/endpoints/{endpoint_id}"=>
  {:PUT=>[:associate_policy_and_endpoint],
   :GET=>[:verify_a_policy_and_endpoint_association],
   :DELETE=>[:delete_a_policy_and_endpoint_association]},
 "/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/services/{service_id}"=>
  {:PUT=>[:associate_policy_and_service_type_endpoint],
   :GET=>[:verify_a_policy_and_service_type_endpoint_association],
   :DELETE=>[:delete_a_policy_and_service_type_endpoint_association]},
 "/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/policy"=>
  {:GET=>[:show_policy_for_endpoint],
   :HEAD=>[:check_policy_and_service_endpoint_association]},
 "/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/services/{service_id}/regions/{region_id}"=>
  {:PUT=>[:associate_policy_and_service_type_endpoint_in_a_region],
   :GET=>[:verify_a_policy_and_service_type_endpoint_in_a_region_association],
   :DELETE=>
    [:delete_a_policy_and_service_type_endpoint_in_a_region_association]},
 "/v3/policies/{policy_id}/OS-ENDPOINT-POLICY/endpoints"=>
  {:GET=>[:list_policy_and_service_endpoint_associations]},
 "/v3/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/policy"=>
  {:GET=>[:show_the_effective_policy_associated_with_an_endpoint]},
 "/v3/OS-OAUTH1/consumers"=>
  {:POST=>[:create_consumer], :GET=>[:list_consumers]},
 "/v3/OS-OAUTH1/consumers/{consumer_id}"=>
  {:DELETE=>[:delete_consumer],
   :GET=>[:show_consumer_details],
   :PATCH=>[:update_consumer]},
 "/v3/OS-OAUTH1/request_token"=>{:POST=>[:create_request_token]},
 "/v3/OS-OAUTH1/authorize/{request_token_id}"=>
  {:PUT=>[:authorize_request_token]},
 "/v3/OS-OAUTH1/access_token"=>{:POST=>[:create_access_token]},
 "/v3/users/{user_id}/OS-OAUTH1/access_tokens/{access_token_id}"=>
  {:GET=>[:get_access_token], :DELETE=>[:revoke_access_token]},
 "/v3/users/{user_id}/OS-OAUTH1/access_tokens"=>{:GET=>[:list_access_tokens]},
 "/v3/users/{user_id}/OS-OAUTH1/access_tokens/{access_token_id}/roles"=>
  {:GET=>[:list_roles_for_an_access_token]},
 "/v3/users/{user_id}/OS-OAUTH1/access_tokens/{access_token_id}/roles/{role_id}"=>
  {:GET=>[:show_role_details_for_an_access_token]},
 "/v3/auth/tokens"=>
  {:POST=>
    [:authenticate_with_identity_api,
     :consuming_a_trust,
     :request_a_scoped_os_federation_token]},
 "/v3/OS-TRUST/trusts"=>{:POST=>[:create_trust], :GET=>[:list_trusts]},
 "/v3/OS-TRUST/trusts/{trust_id}"=>
  {:GET=>[:get_trust], :DELETE=>[:delete_trust]},
 "/v3/OS-TRUST/trusts/{trust_id}/roles"=>
  {:GET=>[:list_roles_delegated_by_a_trust]},
 "/v3/OS-TRUST/trusts/{trust_id}/roles/{role_id}"=>
  {:HEAD=>[:check_if_a_role_is_delegated_by_a_trust],
   :GET=>[:get_role_delegated_by_a_trust]},
 "/v3/OS-REVOKE/events"=>{:GET=>[:list_revocation_events]},
 "/v3/OS-EP-FILTER/endpoint_groups"=>
  {:POST=>[:create_endpoint_group], :GET=>[:list_endpoint_groups]},
 "/v3/OS-EP-FILTER/endpoint_groups/{endpoint_group_id}"=>
  {:GET=>[:get_endpoint_group],
   :HEAD=>[:check_endpoint_group],
   :PATCH=>[:update_endpoint_group],
   :DELETE=>[:delete_endpoint_group]},
 "/v3/OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}"=>
  {:PUT=>[:create_association],
   :HEAD=>[:check_association],
   :DELETE=>[:delete_association]},
 "/v3/OS-EP-FILTER/projects/{project_id}/endpoints"=>
  {:GET=>[:list_associations_by_project]},
 "/v3/OS-EP-FILTER/endpoints/{endpoint_id}/projects"=>
  {:GET=>[:list_associations_by_endpoint]},
 "/v3/OS-EP-FILTER/endpoint_groups/{endpoint_group_id}/projects/{project_id}"=>
  {:PUT=>[:create_endpoint_group_to_project_association],
   :GET=>[:get_endpoint_group_to_project_association],
   :HEAD=>[:check_endpoint_group_to_project_association],
   :DELETE=>[:delete_endpoint_group_to_project_association]},
 "/v3/OS-EP-FILTER/endpoint_groups/{endpoint_group_id}/projects"=>
  {:GET=>[:list_projects_associated_with_endpoint_group]},
 "/v3/OS-EP-FILTER/endpoint_groups/{endpoint_group_id}/endpoints"=>
  {:GET=>[:list_endpoints_associated_with_endpoint_group]},
 "/v3/OS-EP-FILTER/projects/{project_id}/endpoint_groups"=>
  {:GET=>[:list_endpoint_groups_associated_with_project]},
 "/v3/OS-FEDERATION/identity_providers/{id}"=>
  {:PUT=>[:register_an_identity_provider],
   :GET=>[:get_identity_provider],
   :DELETE=>[:delete_identity_provider],
   :PATCH=>[:update_identity_provider]},
 "/v3/OS-FEDERATION/identity_providers"=>{:GET=>[:list_identity_providers]},
 "/v3/OS-FEDERATION/identity_providers/{idp_id}/protocols/{protocol_id}"=>
  {:PUT=>[:add_protocol_to_identity_provider],
   :GET=>[:get_protocol_for_identity_provider],
   :PATCH=>[:update_attribute_mapping_for_identity_provider],
   :DELETE=>[:delete_a_protocol_from_identity_provider]},
 "/v3/OS-FEDERATION/identity_providers/{id}/protocols"=>
  {:GET=>[:list_protocols_of_identity_provider]},
 "/v3/OS-FEDERATION/mappings/{id}"=>
  {:PUT=>[:create_a_mapping],
   :GET=>[:get_a_mapping],
   :PATCH=>[:update_a_mapping],
   :DELETE=>[:delete_a_mapping]},
 "/v3/OS-FEDERATION/mappings"=>{:GET=>[:list_mappings]},
 "/v3/OS-FEDERATION/service_providers/{id}"=>
  {:PUT=>[:register_a_service_provider],
   :GET=>[:get_service_provider],
   :DELETE=>[:delete_service_provider],
   :PATCH=>[:update_service_provider]},
 "/v3/OS-FEDERATION/service_providers"=>{:GET=>[:list_service_providers]},
 "/v3/OS-FEDERATION/projects"=>
  {:GET=>[:list_projects_a_federated_user_can_access]},
 "/v3/OS-FEDERATION/domains"=>
  {:GET=>[:list_domains_a_federated_user_can_access]},
 "/v3/OS-FEDERATION/identity_providers/{idp_id}/protocols/{protocol_id}/auth"=>
  {:GET=>[:request_an_unscoped_os_federation_token]},
 "/v3/auth/OS-FEDERATION/websso/{protocol_id}?origin=https%3A//horizon.example.com"=>
  {:GET=>[:web_single_sign_on_authentication_new_in_version_1_2]},
 "/v3/auth/OS-FEDERATION/identity_providers/{idp_id}/protocol/{protocol_id}/websso?origin=https%3A//horizon.example.com"=>
  {:GET=>[:web_single_sign_on_authentication_new_in_version_1_3]},
 "/v3/auth/OS-FEDERATION/saml2"=>{:POST=>[:generate_a_saml_assertion]},
 "/v3/auth/OS-FEDERATION/saml2/ecp"=>
  {:POST=>[:generate_an_ecp_wrapped_saml_assertion]},
 "/v3/OS-FEDERATION/saml2/metadata"=>{:GET=>[:retrieve_metadata_properties]},
 "/v3/OS-SIMPLE-CERT/ca"=>{:GET=>[:show_ca_certificate]},
 "/v3/OS-SIMPLE-CERT/certificates"=>{:GET=>[:show_signing_certificate]}}
  end
end
